==> nextcloud-31.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/activity/l10n/vi.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Khay hoạt động cá nhân được %s",
    "Your feed URL is invalid" : "Khay URL của bạn không hợp lệ",
    "Activity feed for %1$s" : "Dòng cung cấp dữ liệu hoạt động cho %1$s",
    "Activity feed" : "Nguồn cấp dữ liệu hoạt động",
    "Your settings have been updated." : "Các thiết lập của bạn vừa được cập nhật",
    "Settings have been updated." : "Các cài đặt đã được cập nhật.",
    "Recent activity" : "Hoạt động gần đây",
    "No activities" : "Không có hoạt động",
    "More activities" : "Thêm hoạt động",
    "Daily activity summary for %s" : "Tóm tắt hoạt động hàng ngày cho %s",
    "_and %n more…_::_and %n more…_" : ["và %n còn nữa...."],
    "All activities" : "Tất cả các hoạt động",
    "By others" : "Bởi người khác",
    "By you" : "Bởi bạn",
    "Activity at %s" : "Hoạt động ở %s",
    "Hello %s" : "Xin chào %s",
    "Hello %s," : "Xin chào %s,",
    "There was some activity at %s" : "Có một số hoạt động tại %s",
    "_and %n more _::_and %n more _" : ["và %n thêm"],
    "Mail" : "Thư điện tử",
    "Push" : "Đẩy",
    "Activity" : "Hoạt động",
    "Notifications" : "Thông báo",
    "This application enables people to view a log of activities about them, their files or other data." : "Ứng dụng này cho phép người dùng xem ghi chép cá nhân của họ về: các hoạt động gần đây, tệp tin hoặc dữ liệu khác.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Ứng dụng này cho phép người dùng xem các thao tác liên quan đến tệp tin và dữ liệu của họ trên Nextcloud.\n\t\tMỗi cá nhân có thể cấu hình các cài đặt riêng liên quan đến Hoạt động trong phần Cài đặt Cá nhân,\n\t\tchọn lựa những Hành động nào sẽ được gửi tới điện thoại, hoặc qua email \n\t\thoặc, liệu một bản tóm tắt hàng ngày sẽ được gửi tới vào mỗi buổi sáng .\n\t\tĐể tìm hiểu thêm, vui lòng đọc tài liệu về Hành động.",
    "Send email" : "Gửi email",
    "Send push notification" : "Gửi thông báo đẩy",
    "Activity notification configuration" : "Cấu hình cho thông báo về hoạt động",
    "Today" : "Hôm nay",
    "Yesterday" : "Hôm qua",
    "You need to set up your email address before you can receive notification emails." : "Bạn cần phải thiết lập địa chỉ email trước khi nhận được email thông báo.",
    "Send activity emails" : "Gửi các thư báo về tình trạng hoạt động",
    "As soon as possible" : "Ngay khi có thể",
    "Hourly" : "Hằng giờ",
    "Daily" : "Hằng ngày",
    "Weekly" : "Hằng tuần",
    "You commented" : "Bạn đã bình luận",
    "Message deleted by author" : "Tin nhắn đã xóa bởi tác giả",
    "Open {filename}" : "Mở {filename}",
    "in {path}" : "trong {path}",
    "Home" : "Trang chủ",
    "Could not load activities" : "Không thể tải được các hoạt động.",
    "Loading activities" : "Đang tải các hoạt động",
    "This stream will show events like additions, changes & shares" : "Luồng này sẽ hiển thị các sự kiện như bổ sung, thay đổi & chia sẻ",
    "No activity yet" : "Chưa có hoạt động nào",
    "Loading more activities" : "Đang tải thêm hoạt động.",
    "No more activities." : "Không còn hoạt động nào nữa.",
    "Could not enable RSS link" : "Không thể kích hoạt liên kết RSS.",
    "RSS link copied to clipboard" : "Liên kết RSS đã được sao chép vào bảng tạm.",
    "Could not copy the RSS link, please copy manually:" : "Không thể sao chép liên kết RSS, vui lòng sao chép thủ công:",
    "Activity settings" : "Cài đặt Hành động",
    "Enable RSS feed" : "Bật nguồn cấp dữ liệu RSS",
    "RSS feed" : "Nội dung RSS",
    "Copy RSS feed link" : "Sao chép liên kết RSS",
    "Personal notification settings" : "Cài đặt thông báo cá nhân",
    "Unable to load the activity list" : "Không thể tải danh sách hoạt động",
    "Choose for which activities you want to get an email or push notification." : "Chọn các hoạt động mà bạn muốn nhận email hoặc thông báo đẩy.",
    "Choose for which activities you want to get a push notification." : "Chọn các hoạt động mà bạn muốn nhận thông báo đẩy.",
    "Notification" : "Thông báo",
    "Enable notification emails" : "Bật email thông báo",
    "Daily activity summary" : "Tóm tắt hoạt động trong ngày",
    "Send daily activity summary in the morning" : "Gửi tóm tắt hoạt động hàng ngày vào buổi sáng",
    "Default settings" : "Cài đặt mặc định",
    "Configure the default notification settings for new accounts." : "Thiết lập cài đặt mặc định của phần thông báo cho những tài khoản mới.",
    "Unable to save the settings" : "Không thể lưu cài đặt",
    "No more events to load" : "Không có sự kiện nào"
},
"nplurals=1; plural=0;");

==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/activity/l10n/vi.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Khay hoạt động cá nhân được %s",
    "Your feed URL is invalid" : "Khay URL của bạn không hợp lệ",
    "Activity feed for %1$s" : "Dòng cung cấp dữ liệu hoạt động cho %1$s",
    "Activity feed" : "Nguồn cấp dữ liệu hoạt động",
    "Your settings have been updated." : "Các thiết lập của bạn vừa được cập nhật",
    "Settings have been updated." : "Các cài đặt đã được cập nhật.",
    "remote user" : "người dùng từ xa",
    "Recent activity" : "Hoạt động gần đây",
    "No activities" : "Không có hoạt động",
    "More activities" : "Thêm hoạt động",
    "Daily activity summary for %s" : "Tóm tắt hoạt động hàng ngày cho %s",
    "_and %n more…_::_and %n more…_" : ["và %n còn nữa...."],
    "All activities" : "Tất cả các hoạt động",
    "By others" : "Bởi người khác",
    "By you" : "Bởi bạn",
    "Activity at %s" : "Hoạt động ở %s",
    "Hello %s" : "Xin chào %s",
    "Hello %s," : "Xin chào %s,",
    "There was some activity at %s" : "Có một số hoạt động tại %s",
    "_and %n more _::_and %n more _" : ["và %n thêm"],
    "You can change the frequency of these emails or disable them in the settings: %s" : "Bạn có thể thay đổi tần suất nhận những email này hoặc tắt chúng trong cài đặt: %s",
    "Mail" : "Thư điện tử",
    "Push" : "Đẩy",
    "Activity" : "Hoạt động",
    "Notifications" : "Thông báo",
    "This application enables people to view a log of activities about them, their files or other data." : "Ứng dụng này cho phép người dùng xem ghi chép cá nhân của họ về: các hoạt động gần đây, tệp tin hoặc dữ liệu khác.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Ứng dụng này cho phép người dùng xem các thao tác liên quan đến tệp tin và dữ liệu của họ trên Nextcloud.\n\t\tMỗi cá nhân có thể cấu hình các cài đặt riêng liên quan đến Hoạt động trong phần Cài đặt Cá nhân,\n\t\tchọn lựa những Hành động nào sẽ được gửi tới điện thoại, hoặc qua email \n\t\thoặc, liệu một bản tóm tắt hàng ngày sẽ được gửi tới vào mỗi buổi sáng .\n\t\tĐể tìm hiểu thêm, vui lòng đọc tài liệu về Hành động.",
    "Send email" : "Gửi email",
    "Send push notification" : "Gửi thông báo đẩy",
    "Activity notification configuration" : "Cấu hình cho thông báo về hoạt động",
    "Today" : "Hôm nay",
    "Yesterday" : "Hôm qua",
    "You need to set up your email address before you can receive notification emails." : "Bạn cần phải thiết lập địa chỉ email trước khi nhận được email thông báo.",
    "Send activity emails" : "Gửi các thư báo về tình trạng hoạt động",
    "As soon as possible" : "Ngay khi có thể",
    "Hourly" : "Hằng giờ",
    "Daily" : "Hằng ngày",
    "Weekly" : "Hằng tuần",
    "You commented" : "Bạn đã bình luận",
    "Message deleted by author" : "Tin nhắn đã xóa bởi tác giả",
    "Open {filename}" : "Mở {filename}",
    "in {path}" : "trong {path}",
    "Home" : "Trang chủ",
    "Could not load activities" : "Không thể tải được các hoạt động.",
    "Loading activities" : "Đang tải các hoạt động",
    "This stream will show events like additions, changes & shares" : "Luồng này sẽ hiển thị các sự kiện như bổ sung, thay đổi & chia sẻ",
    "No activity yet" : "Chưa có hoạt động nào",
    "Loading more activities" : "Đang tải thêm hoạt động.",
    "No more activities." : "Không còn hoạt động nào nữa.",
    "Could not enable RSS link" : "Không thể kích hoạt liên kết RSS.",
    "RSS link copied to clipboard" : "Liên kết RSS đã được sao chép vào bảng tạm.",
    "Could not copy the RSS link, please copy manually:" : "Không thể sao chép liên kết RSS, vui lòng sao chép thủ công:",
    "Activity settings" : "Cài đặt Hành động",
    "Enable RSS feed" : "Bật nguồn cấp dữ liệu RSS",
    "RSS feed" : "Nội dung RSS",
    "Copy RSS feed link" : "Sao chép liên kết RSS",
    "Personal notification settings" : "Cài đặt thông báo cá nhân",
    "Unable to load the activity list" : "Không thể tải danh sách hoạt động",
    "Choose for which activities you want to get an email or push notification." : "Chọn các hoạt động mà bạn muốn nhận email hoặc thông báo đẩy.",
    "Choose for which activities you want to get a push notification." : "Chọn các hoạt động mà bạn muốn nhận thông báo đẩy.",
    "Notification" : "Thông báo",
    "Enable notification emails" : "Bật email thông báo",
    "Daily activity summary" : "Tóm tắt hoạt động trong ngày",
    "Send daily activity summary in the morning" : "Gửi tóm tắt hoạt động hàng ngày vào buổi sáng",
    "Default settings" : "Cài đặt mặc định",
    "Configure the default notification settings for new accounts." : "Thiết lập cài đặt mặc định của phần thông báo cho những tài khoản mới.",
    "Unable to save the settings" : "Không thể lưu cài đặt",
    "No more events to load" : "Không có sự kiện nào"
},
"nplurals=1; plural=0;");
